@@ -6,6 +6,7 @@
 #include "status-file.h"
 #include "static_threads.h"
 #include "web/api/queries/backfill.h"
+#include "web/mcp/mcp.h"
 
 #include "database/engine/page_test.h"
 #include <curl/curl.h>
@@ -858,7 +859,6 @@ int netdata_main(int argc, char **argv) {
 
     // ----------------------------------------------------------------------------------------------------------------
     delta_startup_time("temp spawn server");
-
     netdata_main_spawn_server_init("init", argc, (const char **)argv);
 
     // ----------------------------------------------------------------------------------------------------------------
@@ -945,6 +945,7 @@ int netdata_main(int argc, char **argv) {
     // get the certificate and start security
     netdata_conf_web_security_init();
     nd_web_api_init();
+    mcp_initialize_subsystem();
     web_server_threading_selection();
 
     delta_startup_time("web server sockets");
@@ -980,7 +981,6 @@ int netdata_main(int argc, char **argv) {
 
     // ----------------------------------------------------------------------------------------------------------------
     delta_startup_time("stop temporary spawn server");
-
     // stop the old server and later start a new one under the new permissions
     netdata_main_spawn_server_cleanup();
 
